Module blaxel.core.client.models.workspace
==========================================

Classes
-------

`Workspace(created_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, updated_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, created_by: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, updated_by: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, account_id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, display_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, labels: blaxel.core.client.types.Unset | ForwardRef('WorkspaceLabels') = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, region: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, runtime: blaxel.core.client.types.Unset | ForwardRef('WorkspaceRuntime') = <blaxel.core.client.types.Unset object>)`
:   Workspace
    
    Attributes:
        created_at (Union[Unset, str]): The date and time when the resource was created
        updated_at (Union[Unset, str]): The date and time when the resource was updated
        created_by (Union[Unset, str]): The user or service account who created the resource
        updated_by (Union[Unset, str]): The user or service account who updated the resource
        account_id (Union[Unset, str]): Workspace account id
        display_name (Union[Unset, str]): Workspace display name
        id (Union[Unset, str]): Autogenerated unique workspace id
        labels (Union[Unset, WorkspaceLabels]): Workspace labels
        name (Union[Unset, str]): Workspace name
        region (Union[Unset, str]): Workspace write region
        runtime (Union[Unset, WorkspaceRuntime]): Workspace runtime
    
    Method generated by attrs for class Workspace.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `account_id`
    :

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `created_at`
    :

    `created_by`
    :

    `display_name`
    :

    `id`
    :

    `labels`
    :

    `name`
    :

    `region`
    :

    `runtime`
    :

    `updated_at`
    :

    `updated_by`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :